@@ -1,3 +1,6 @@
+"""
+Data API query functions for [IEX](https://iexcloud.io/) stock data.
+"""
 from algora.api.data.iex.stocks.asynchronous import (
     async_symbols, async_historical_prices, async_news, async_peer_group
 )
