@@ -14,7 +14,7 @@ from algora.common.function import to_pandas_with_index, no_transform
 from algora.common.requests import __get_request
 
 
-@data_request(transformer=lambda data: to_pandas_with_index(data, index='execution_timestamp'))
+@data_request(transformers=[lambda data: to_pandas_with_index(data, index='execution_timestamp')])
 def get_by_date(asset_class: AssetClass, date: str, repos: Optional[List[Repository]] = None) -> DataFrame:
     """
     Get all SDR data by asset class, date and repositories.
@@ -31,7 +31,7 @@ def get_by_date(asset_class: AssetClass, date: str, repos: Optional[List[Reposit
     return __get_request(**request_info)
 
 
-@data_request(transformer=no_transform)
+@data_request(transformers=[no_transform])
 def get_distinct_in_field(asset_class: AssetClass, field: str) -> List[str]:
     """
     Get all distinct values in field.
