@@ -18,7 +18,7 @@ from algora.common.requests import (
 )
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_get_client_id():
     """
     Asynchronously get keycloak client ID.
@@ -42,7 +42,7 @@ async def async_get_users(limit: int = 500, page_offset: int = 0):
     return await __async_get_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_get_user_count():
     """
     Get the total number of users.
@@ -54,7 +54,7 @@ async def async_get_user_count():
     return await __async_get_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_get_user(user_id: str):
     """
     Asynchronously get user by ID.
@@ -69,7 +69,7 @@ async def async_get_user(user_id: str):
     return await __async_get_request(**request_info)
 
 
-@async_data_request(transformer=no_transform, processor=lambda r: r)
+@async_data_request(transformers=[no_transform], processor=lambda r: r)
 def async_execute_actions_email(user_id: str, actions: List[str], client_id: str, redirect_uri: str):
     """
     Asynchronously update user.
@@ -87,7 +87,7 @@ def async_execute_actions_email(user_id: str, actions: List[str], client_id: str
     return __async_put_request(**request_info)
 
 
-@async_data_request(transformer=no_transform, processor=lambda r: r)
+@async_data_request(transformers=[no_transform], processor=lambda r: r)
 async def async_update_user(user_id: str, data: dict):
     """
     Asynchronously update user.
@@ -103,7 +103,7 @@ async def async_update_user(user_id: str, data: dict):
     return await __async_put_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_get_groups():
     """
     Asynchronously get groups.
@@ -115,7 +115,7 @@ async def async_get_groups():
     return await __async_get_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_get_group_members(id: str):
     """
     Asynchronously get group members given group ID.
@@ -130,7 +130,7 @@ async def async_get_group_members(id: str):
     return await __async_get_request(**request_info)
 
 
-@async_data_request(transformer=no_transform, processor=lambda r: r)
+@async_data_request(transformers=[no_transform], processor=lambda r: r)
 async def async_add_group_to_user(user_id: str, group_id: str):
     """
     Asynchronously add user to group.
@@ -146,7 +146,7 @@ async def async_add_group_to_user(user_id: str, group_id: str):
     return await __async_put_request(**request_info)
 
 
-@async_data_request(transformer=no_transform, processor=lambda r: r)
+@async_data_request(transformers=[no_transform], processor=lambda r: r)
 async def async_delete_group_from_user(user_id: str, group_id: str):
     """
     Asynchronously delete user from group.
@@ -162,7 +162,7 @@ async def async_delete_group_from_user(user_id: str, group_id: str):
     return await __async_delete_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_get_roles():
     """
     Asynchronously get roles.
@@ -174,7 +174,7 @@ async def async_get_roles():
     return await __async_get_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_get_roles_for_user(user_id: str):
     """
     Asynchronously get roles for user.
@@ -189,7 +189,7 @@ async def async_get_roles_for_user(user_id: str):
     return await __async_get_request(**request_info)
 
 
-@async_data_request(transformer=no_transform, processor=lambda r: r)
+@async_data_request(transformers=[no_transform], processor=lambda r: r)
 async def async_add_role_mapping_to_user(user_id: str, role_ids: List[Dict[str, str]]):
     """
     Asynchronously add role mapping to user.
@@ -205,7 +205,7 @@ async def async_add_role_mapping_to_user(user_id: str, role_ids: List[Dict[str,
     return await __async_post_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_get_offline_token(user_id: str) -> dict:
     """
     Asynchronously get offline token for user.
@@ -220,7 +220,7 @@ async def async_get_offline_token(user_id: str) -> dict:
     return await __async_get_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_create_offline_token(user_id: str, refresh_token: str, exp: Optional[int] = None) -> dict:
     """
     Asynchronously create offline token for user.
@@ -237,7 +237,7 @@ async def async_create_offline_token(user_id: str, refresh_token: str, exp: Opti
     return await __async_put_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_update_offline_token(user_id: str, refresh_token: str, exp: Optional[int] = None) -> dict:
     """
     Asynchronously update offline token for user.
@@ -254,7 +254,7 @@ async def async_update_offline_token(user_id: str, refresh_token: str, exp: Opti
     return await __async_post_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_delete_offline_token(user_id: str) -> None:
     """
     Asynchronously delete offline token for user.
