@@ -2,8 +2,8 @@
 Auth API.
 """
 from algora.api.service.auth.asynchronous import (
-    async_login, async_refresh_token
+    async_login, async_refresh_token, async_exchange_token
 )
 from algora.api.service.auth.synchronous import (
-    login, refresh_token
+    login, refresh_token, exchange_token
 )
