@@ -1,5 +1,8 @@
 from typing import Optional
 
+from algora.common.config import EnvironmentConfig
+
+config = EnvironmentConfig()
 
 def _login_request_info(username: str, password: str, scope: Optional[str] = None) -> dict:
     data = {
@@ -12,14 +15,14 @@ def _login_request_info(username: str, password: str, scope: Optional[str] = Non
         data.update({'scope': scope})
 
     return {
-        "url": f"https://auth.algoralabs.com/auth/realms/production/protocol/openid-connect/token",
+        "url": f"{config.get_url('keycloak')}/protocol/openid-connect/token",
         "data": data
     }
 
 
 def _refresh_token_request_info(refresh_token: Optional[str] = None) -> dict:
     return {
-        "url": f"https://auth.algoralabs.com/auth/realms/production/protocol/openid-connect/token",
+        "url": f"{config.get_url('keycloak')}/protocol/openid-connect/token",
         "data": {
             "client_id": "algora-api",
             "grant_type": "refresh_token",
@@ -38,6 +41,6 @@ def _token_exchange_request_info(requested_subject: str, subject_token: str) ->
     }
 
     return {
-        "url": f"https://auth.algoralabs.com/auth/realms/production/protocol/openid-connect/token",
+        "url": f"{config.get_url('keycloak')}/protocol/openid-connect/token",
         "data": data
     }
