@@ -11,13 +11,13 @@ from algora.common.function import no_transform
 from algora.common.requests import __post_request
 
 
-@data_request(transformer=no_transform)
+@data_request(transformers=[no_transform])
 def analyze_data(data: pd.DataFrame) -> Dict[str, Any]:
     request_info = _analyze_data_request_info(data)
     return __post_request(**request_info)
 
 
-@data_request(processor=lambda r: r.content, transformer=lambda r: pd.read_parquet(io.BytesIO(r)))
+@data_request(processor=lambda r: r.content, transformers=[lambda r: pd.read_parquet(io.BytesIO(r))])
 def transform_data(data: pd.DataFrame, transform_override: Optional[TransformOverride] = None) -> DataFrame:
     request_info = _transform_data_request_info(data, transform_override)
     return __post_request(**request_info)
