@@ -2,9 +2,10 @@
 Project Package API
 """
 from algora.api.service.project.package.synchronous import (
-    get_project_packages, get_project_package, create_project_package, update_project_package, delete_project_package
+    get_project_packages, get_project_package, create_project_package, update_project_package, delete_project_package,
+    search_project_packages
 )
 from algora.api.service.project.package.asynchronous import (
     async_get_project_packages, async_get_project_package, async_create_project_package,
-    async_update_project_package, async_delete_project_package
+    async_update_project_package, async_delete_project_package, async_search_project_packages
 )
