@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Optional
 
 from algora.api.service.project.package.model import ProjectPackageRequest
 
@@ -11,13 +11,23 @@ def _get_project_package_request_info(id: str) -> dict:
 
 def _get_project_packages_request_info() -> dict:
     return {
-        'endpoint': f"config/project/package"
+        'endpoint': f"config/project/package",
     }
 
 
-def _search_project_packages_request_info(name: str, version: str) -> dict:
+def _search_project_packages_request_info(
+        name: Optional[str] = None,
+        version: Optional[str] = None,
+        tag: Optional[str] = None
+) -> dict:
+    params = {
+        'name': name,
+        'version': version,
+        'tag': tag
+    }
     return {
-        'endpoint': f"config/project/package/search?name={name}&version={version}"
+        'endpoint': f"config/project/package/search",
+        'params': {k: v for k, v in params.items() if v}
     }
 
 
