@@ -7,7 +7,7 @@ from algora.common.requests import __put_request, __delete_request
 
 
 @data_request(
-    transformer=no_transform,
+    transformers=[no_transform],
     processor=lambda response: response.status_code
 )
 def upload_resources(path: str, file_locations: List[str]) -> Dict[str, Any]:
@@ -29,7 +29,7 @@ def upload_resources(path: str, file_locations: List[str]) -> Dict[str, Any]:
 
 
 @data_request(
-    transformer=no_transform,
+    transformers=[no_transform],
     processor=lambda response: response.status_code
 )
 def delete_resource(path: str) -> Dict[str, Any]:
