@@ -4,6 +4,8 @@ Configuration classes used for configuring the Algora SDK.
 import os
 from typing import Optional
 
+from typing_extensions import Literal
+
 
 class Auth:
     """
@@ -54,14 +56,31 @@ class EnvironmentConfig:
     """
     Configuration class for getting environment information.
     """
-    urls: dict = {
-        'algora': 'https://api.algoralabs.com',
-        'keycloak_admin': 'https://auth.algoralabs.com/auth/admin/realms/production',
-        'keycloak': 'https://auth.algoralabs.com/auth/realms/production',
-        'fred': 'https://api.stlouisfed.org/fred'
-    }
     auth_config: Auth = Auth()
 
+    @property
+    def environment(self) -> str:
+        env = os.getenv("ALGORA_ENV", 'production')
+        return env
+
+    @property
+    def urls(self) -> dict:
+        env_url_map = {
+            "production": {
+                'algora': 'https://api.algoralabs.com',
+                'keycloak_admin': 'https://auth.algoralabs.com/auth/admin/realms/production',
+                'keycloak': 'https://auth.algoralabs.com/auth/realms/production',
+                'fred': 'https://api.stlouisfed.org/fred'
+            },
+            'development': {
+                'algora': 'https://api.dev.algoralabs.com',
+                'keycloak_admin': 'https://auth.dev.algoralabs.com/auth/admin/realms/production',
+                'keycloak': 'https://auth.dev.algoralabs.com/auth/realms/production',
+                'fred': 'https://api.stlouisfed.org/fred'
+            }
+        }
+        return env_url_map.get(self.environment, env_url_map['production'])
+
     def get_url(self, key: str = "algora") -> str:
         """
         Get base URL given key.
