@@ -1,5 +1,5 @@
 import functools
-from typing import Tuple, Dict, Any, Callable
+from typing import Tuple, Dict, Any, Callable, List
 
 import pandas as pd
 from requests import Response
@@ -11,7 +11,7 @@ def data_request(
         request: Callable = None,
         *,
         processor: Callable[[Response], Any] = lambda response: response.json(),
-        transformer: Callable[[Any], Any] = lambda data: pd.DataFrame(data)
+        transformers: List[Callable[[Any], Any]] = None
 ) -> Callable:
     """
     Decorator for processing the response of a REST request.
@@ -19,7 +19,7 @@ def data_request(
     Args:
         request (Callable): Function
         processor (Callable[[Response], Any]): Transform response
-        transformer (Callable[[Any], Any]): Transform data output
+        transformers (Callable[[Any], Any]): List of transform functions to run the data through in order
 
     Returns:
         Callable: Wrapped function
@@ -30,9 +30,9 @@ def data_request(
         @functools.wraps(f)
         def wrap(*args: Tuple, **kwargs: Dict[str, Any]) -> Any:
             _processor = kwargs.pop('processor', None) or processor
-            _transformer = kwargs.pop('transformer', None) or transformer
+            _transformers = kwargs.pop('transformers', None) or transformers or [lambda data: pd.DataFrame(data)]
             response: Response = f(*args, **kwargs)
-            return __process_response(response, _processor, _transformer)
+            return __process_response(response, _processor, _transformers)
 
         return wrap
 
