@@ -9,6 +9,7 @@ from pydantic import Field as pyField
 from algora.common.base import Base
 from algora.common.enum import FieldType
 from algora.common.type import Datetime
+from algora.quant.instrument.common.cut import BaseObservationCut
 
 
 class Field(Base):
@@ -24,3 +25,10 @@ class DataRequest(Base):
     start_date: Optional[datetime] = pyField(default=None)
     end_date: Optional[datetime] = pyField(default=None)
     as_of: Optional[datetime] = pyField(default=None)
+
+
+class DataDefinition(Base):
+    """
+    Base data definition.
+    """
+    cut: Optional[BaseObservationCut] = pyField(default=None)
